==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Layer/ts/Layer_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+66"/>
        <source>Layer Tools</source>
        <translation>Laag gereedschappen</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Laag gereedschappen tonen</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;Laag</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Showing all layers</source>
        <translation>Alle laagen tonen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation>Alle laagen verbergen</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Locking all layers</source>
        <translation>Alle laagen vergrendelen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation>Alle laagen ontgrendelen</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+176"/>
        <source>Leading or trailing spaces.</source>
        <translation>Spaties voor of na.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translation>Naam van de laag is leeg.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translation>Laag bestaat al.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translation>Laag</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>Naam van de laag:</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Attributen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Kleur:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translation>Lijndikte:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translation>Lijntype:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Layer/ts/Layer_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+97"/>
        <source>Layer Tools</source>
        <translation>Laag gereedschappen</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Laag gereedschappen tonen</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;Laag</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Showing all layers</source>
        <translation>Alle laagen tonen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation>Alle laagen verbergen</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Thawing all layers</source>
        <translation>Alle laagen ontdooien</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Freezing all layers</source>
        <translation>Alle laagen bevriezen</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Locking all layers</source>
        <translation>Alle laagen vergrendelen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation>Alle laagen ontgrendelen</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+191"/>
        <source>Leading or trailing spaces.</source>
        <translation>Spaties voor of na.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Layer name is empty.</source>
        <translation>Naam van de laag is leeg.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Layer already exists.</source>
        <translation>Laag bestaat al.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translation>Laag</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>Naam van de laag:</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Attributen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Kleur:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translation>Lijndikte:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translation>Lijntype:</translation>
    </message>
</context>
</TS>
